# 004

|                                                | Asko professional tumble dryer   |
|:-----------------------------------------------|:---------------------------------|
| bindTime                                       | 1614938571640                    |
| createTime                                     | 0                                |
| deviceFeatureCode                              | 000                              |
| deviceFeatureName                              | ASKO Pro Dryer                   |
| deviceId                                       | <redacted>                       |
| deviceNickName                                 | TD Aandrej                       |
| deviceTypeCode                                 | 004                              |
| deviceTypeName                                 | ASKO Pro Dryer                   |
| offlineState                                   | 1                                |
| puid                                           | <redacted>                       |
| role                                           | 1                                |
| roomId                                         | 106345                           |
| roomName                                       | default_room                     |
| seq                                            | 0                                |
| statusList.ACTION                              | 0                                |
| statusList.AlarmCleanCondense                  | 0                                |
| statusList.AlarmCleanCondenserFilter           | 0                                |
| statusList.AlarmCleanDoorFilter                | 0                                |
| statusList.AlarmCloseTheDoorWarning            | 0                                |
| statusList.AlarmFullTank                       | 0                                |
| statusList.AlarmPowerFail                      | 0                                |
| statusList.AlarmProgramFinished                | 0                                |
| statusList.AlramEmptyWaterTank                 | 0                                |
| statusList.BlockDetailedProgramView            | 1                                |
| statusList.BookAvailableTime                   | 9196                             |
| statusList.BookReservedTime                    | 0                                |
| statusList.BookTimeToEndReservation            | 10                               |
| statusList.Booking                             | 0                                |
| statusList.ChildLockActive                     | 0                                |
| statusList.ChildLockEnabled                    | 0                                |
| statusList.CleanCondenseFilter                 | 10                               |
| statusList.CleanDoorFilter                     | 1                                |
| statusList.CondenseWaterMode                   | 0                                |
| statusList.CondenseWaterModeSet                | 0                                |
| statusList.DemoMode                            | 0                                |
| statusList.DeviceStatus                        | 6                                |
| statusList.DisplayBrightness                   | 2                                |
| statusList.DisplayLogo                         | 1                                |
| statusList.DoorStatus                          | 0                                |
| statusList.EmptyWaterTank                      | 1                                |
| statusList.Error0                              | 0                                |
| statusList.Error1                              | 0                                |
| statusList.Error10                             | 0                                |
| statusList.Error11                             | 0                                |
| statusList.Error12                             | 0                                |
| statusList.Error13                             | 0                                |
| statusList.Error14                             | 0                                |
| statusList.Error15                             | 0                                |
| statusList.Error2                              | 0                                |
| statusList.Error3                              | 0                                |
| statusList.Error4                              | 0                                |
| statusList.Error5                              | 0                                |
| statusList.Error6                              | 0                                |
| statusList.Error7                              | 0                                |
| statusList.Error8                              | 0                                |
| statusList.Error9                              | 0                                |
| statusList.FailureReadOut1                     | 0                                |
| statusList.FailureReadOut10                    | 9                                |
| statusList.FailureReadOut10LastCycle           | 0                                |
| statusList.FailureReadOut10NumberOfRepetiotion | 0                                |
| statusList.FailureReadOut11                    | 10                               |
| statusList.FailureReadOut11NumberOfRepetiotion | 0                                |
| statusList.FailureReadOut12                    | 11                               |
| statusList.FailureReadOut12NumberOfRepetiotion | 1                                |
| statusList.FailureReadOut1LastCycle            | 0                                |
| statusList.FailureReadOut1NumberOfRepetiotion  | 0                                |
| statusList.FailureReadOut2                     | 1                                |
| statusList.FailureReadOut2LastCycle            | 0                                |
| statusList.FailureReadOut2NumberOfRepetiotion  | 1                                |
| statusList.FailureReadOut3                     | 2                                |
| statusList.FailureReadOut3LastCycle            | 0                                |
| statusList.FailureReadOut3NumberOfRepetiotion  | 0                                |
| statusList.FailureReadOut4                     | 3                                |
| statusList.FailureReadOut4LastCycle            | 0                                |
| statusList.FailureReadOut4NumberOfRepetiotion  | 0                                |
| statusList.FailureReadOut5                     | 4                                |
| statusList.FailureReadOut5LastCycle            | 0                                |
| statusList.FailureReadOut5NumberOfRepetiotion  | 0                                |
| statusList.FailureReadOut6                     | 5                                |
| statusList.FailureReadOut6LastCycle            | 0                                |
| statusList.FailureReadOut6NumberOfRepetiotion  | 21                               |
| statusList.FailureReadOut7                     | 6                                |
| statusList.FailureReadOut7LastCycle            | 0                                |
| statusList.FailureReadOut7NumberOfRepetiotion  | 0                                |
| statusList.FailureReadOut8                     | 7                                |
| statusList.FailureReadOut8LastCycle            | 0                                |
| statusList.FailureReadOut8NumberOfRepetiotion  | 0                                |
| statusList.FailureReadOut9                     | 8                                |
| statusList.FailureReadOut9LastCycle            | 0                                |
| statusList.FailureReadOut9NumberOfRepetiotion  | 0                                |
| statusList.HardPairingStatus                   | 0                                |
| statusList.Heater2Enable                       | 0                                |
| statusList.HumiditySensor                      | 0                                |
| statusList.IDMachine                           | 2673                             |
| statusList.Identified                          | 0                                |
| statusList.Language                            | 16                               |
| statusList.PPUOnlineCoinSystem                 | 0                                |
| statusList.PPURECIPSS                          | 0                                |
| statusList.PPUWashEnabled                      | 0                                |
| statusList.PaidByCoinBoxOrEADBS                | 0                                |
| statusList.ParseLibVersion                     | 500525                           |
| statusList.PaymentEnabledTimer                 | 0                                |
| statusList.PaymentSystem                       | 0                                |
| statusList.ProgramOptionAnticrease             | 0                                |
| statusList.ProgramTimesStartDelayHours         | 0                                |
| statusList.RemoteControlMode                   | 2                                |
| statusList.RemoteStartDuration                 | 10                               |
| statusList.RemoteStartEnabled                  | 1                                |
| statusList.SelectedBasicID                     | 0                                |
| statusList.SelectedDerivedID                   | 0                                |
| statusList.SelectedProgram                     | 0                                |
| statusList.SessionPairingActive                | 3                                |
| statusList.SessionPairingConfirmation          | 0                                |
| statusList.SessionPairingRequest               | 0                                |
| statusList.SessionPairingSetting               | 1                                |
| statusList.SoftPairingSetting                  | 1                                |
| statusList.StandbyChoice                       | 0                                |
| statusList.StartDelayFunction                  | 1                                |
| statusList.TemperatureSensor1                  | 0                                |
| statusList.TemperatureSensor2                  | 30                               |
| statusList.TemporaryLanguageSelected           | 16                               |
| statusList.TemporaryLanguageSettingEnabled     | 1                                |
| statusList.TimeIconSetting                     | 1                                |
| statusList.TimeRemaining                       | 0                                |
| statusList.TotalProgramsCycles                 | 323                              |
| statusList.Volume                              | 3                                |
| statusList.daily_energy_kwh                    | 0                                |
| statusList.reserved105                         | 0                                |
| statusList.reserved106                         | 0                                |
| statusList.reserved107                         | 0                                |
| statusList.reserved110                         | 0                                |
| statusList.reserved111                         | 0                                |
| statusList.reserved112                         | 0                                |
| statusList.reserved113                         | 0                                |
| statusList.reserved114                         | 0                                |
| statusList.reserved115                         | 0                                |
| statusList.reserved116                         | 0                                |
| statusList.reserved117                         | 0                                |
| statusList.reserved118                         | 0                                |
| statusList.reserved128                         | 0                                |
| statusList.reserved129                         | 0                                |
| statusList.reserved130                         | 0                                |
| statusList.reserved14                          | 0                                |
| statusList.reserved18                          | 0                                |
| statusList.reserved20                          | 0                                |
| statusList.reserved8                           | 0                                |
| statusList.reserved83                          | 0                                |
| statusList.reserved9                           | 0                                |
| useTime                                        | 0                                |
| wifiId                                         | <redacted>                       |

## Generated from

- [`Asko_professional_tumble_dryer.json`](Asko_professional_tumble_dryer.json)
